from __future__ import absolute_import
from __future__ import division
from __future__ import print_function
from __future__ import unicode_literals

# noinspection PyUnresolvedReferences
from prompt_toolkit.validation import Validator, ValidationError

import questionary.version
from questionary.prompt import prompt
from questionary.prompts.common import Separator

__version__ = questionary.version.__version__



# -*- coding: utf-8 -*-
from __future__ import print_function, unicode_literals

from questionary.prompts import input


def question(message, **kwargs):
    return input.question(message, is_password=True, **kwargs)
